pub struct MessageWithFds {
pub message: JsonRpcMessage,
pub file_descriptors: Vec<OwnedFd>,
}Expand description
A JSON-RPC message paired with file descriptors to send or that were received.
Fields
message: JsonRpcMessageThe JSON-RPC message.
file_descriptors: Vec<OwnedFd>File descriptors attached to this message.
Implementations
Sourceimpl MessageWithFds
impl MessageWithFds
Sourcepub fn new(message: JsonRpcMessage, file_descriptors: Vec<OwnedFd>) -> Self
pub fn new(message: JsonRpcMessage, file_descriptors: Vec<OwnedFd>) -> Self
Create a new message with file descriptors.
Sourcepub fn serialize(&self) -> Result<String>
pub fn serialize(&self) -> Result<String>
Serialize the message, setting the fds field to match the number of attached FDs.
Sourcepub fn serialize_pretty(&self) -> Result<String>
pub fn serialize_pretty(&self) -> Result<String>
Serialize the message with pretty-printing.