pub struct Receiver { /* private fields */ }Expand description
Receiver half of a Unix socket transport for receiving JSON-RPC messages.
Implementations
Sourceimpl Receiver
impl Receiver
Sourcepub async fn receive(&mut self) -> Result<MessageWithFds>
pub async fn receive(&mut self) -> Result<MessageWithFds>
Receive a message, returning an error on connection close.
See also receive_opt which returns Ok(None)
on connection close instead of an error.
Sourcepub async fn receive_opt(&mut self) -> Result<Option<MessageWithFds>>
pub async fn receive_opt(&mut self) -> Result<Option<MessageWithFds>>
Receive a message, returning Ok(None) on connection close.
This is a convenience method that converts Error::ConnectionClosed
to Ok(None), which is useful for receiver loops:
ⓘ
while let Some(msg) = receiver.receive_opt().await? {
// handle message
}See also receive which returns an error on
connection close.