pub type MethodHandler = Box<dyn Fn(&str, Option<Value>, Vec<OwnedFd>) -> Result<(Option<Value>, Vec<OwnedFd>)> + Send + Sync>;Expand description
Handler function for JSON-RPC methods.
Takes the method name, optional parameters, and received file descriptors. Returns the result value and any file descriptors to send with the response.
Aliased Type
pub struct MethodHandler(/* private fields */);